import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.ReplicationSlot`` resource creates and manages a replication slot on a PostgreSQL
 * server.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const mySlot = new postgresql.ReplicationSlot("my_slot", {
 *     name: "my_slot",
 *     plugin: "test_decoding",
 * });
 * ```
 */
export declare class ReplicationSlot extends pulumi.CustomResource {
    /**
     * Get an existing ReplicationSlot resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ReplicationSlotState, opts?: pulumi.CustomResourceOptions): ReplicationSlot;
    /**
     * Returns true if the given object is an instance of ReplicationSlot.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReplicationSlot;
    /**
     * Which database to create the replication slot on. Defaults to provider database.
     */
    readonly database: pulumi.Output<string>;
    /**
     * The name of the replication slot.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Sets the output plugin.
     */
    readonly plugin: pulumi.Output<string>;
    /**
     * Create a ReplicationSlot resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicationSlotArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ReplicationSlot resources.
 */
export interface ReplicationSlotState {
    /**
     * Which database to create the replication slot on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * The name of the replication slot.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the output plugin.
     */
    plugin?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ReplicationSlot resource.
 */
export interface ReplicationSlotArgs {
    /**
     * Which database to create the replication slot on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * The name of the replication slot.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the output plugin.
     */
    plugin: pulumi.Input<string>;
}
